package com.ekexiu.portal.service;

import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;

import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.DefaultValue;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Delete;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.operate.Post;
import org.jfw.apt.web.annotation.operate.Put;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.apt.web.annotation.param.PathVar;
import org.jfw.apt.web.annotation.param.RequestBody;
import org.jfw.util.PageQueryResult;
import org.jfw.util.StringUtil;

import com.ekexiu.portal.dao.ImageDao;
import com.ekexiu.portal.dao.ResourceDao;
import com.ekexiu.portal.po.Resource;

@Path("/resource")
public class ResourceService {
	@Autowrie
	private ImageDao imageDao;
	@Autowrie
	private ResourceDao resourceDao;
	@Autowrie
	private ImagesService imagesService;

	public ImageDao getImageDao() {
		return imageDao;
	}

	public void setImageDao(ImageDao imageDao) {
		this.imageDao = imageDao;
	}

	public ResourceDao getResourceDao() {
		return resourceDao;
	}

	public void setResourceDao(ResourceDao resourceDao) {
		this.resourceDao = resourceDao;
	}

	public ImagesService getImagesService() {
		return imagesService;
	}

	public void setImagesService(ImagesService imagesService) {
		this.imagesService = imagesService;
	}

	@Post
	@Path
	public String insert(@JdbcConn(true) Connection con, Resource resource, String fn) {
		String resourceId = StringUtil.buildUUID();
		try {
			this.imagesService.insert(con, resourceId, fn);
			resource.setResourceId(resourceId);
			this.resourceDao.insert(con, resource);
		} catch (SQLException | IOException e) {
			try {
				con.rollback();
			} catch (SQLException e1) {
				e1.printStackTrace();
			}
			e.printStackTrace();
		}
		return resourceId;
	}

	@Put
	@Path
	public void update(@JdbcConn(true) Connection con, @RequestBody Resource resource, @Nullable String professorId) throws SQLException {
		if (resource.getProfessorId() != null)
			resource.setProfessorId(professorId);
		this.resourceDao.update(con, resource);
	}

	@Get
	@Path("/{resourceId}")
	public Resource query(@JdbcConn Connection con, @PathVar String resourceId) throws SQLException {
		return this.resourceDao.query(con, resourceId);
	}
	
	@Get
	@Path("/pqall")
	public PageQueryResult<Resource> queryPageAll(@JdbcConn Connection con, @DefaultValue("10") int pageSize, @DefaultValue("1") int pageNo) throws SQLException {
		return this.resourceDao.queryPageAll(con, pageSize, pageNo);
	}

//	@Get
//	@Path("/qa")
//	public List<Resource> queryAll(@JdbcConn Connection con) throws SQLException {
//		return this.resourceDao.query(con);
//	}
	
	@Get
	@Path("/qapro")
	public List<Resource> queryPro(@JdbcConn Connection con, String professorId) throws SQLException {
		return this.resourceDao.queryPro(con, professorId);
	}
	
	@Post
	@Path("/subject")
	public void updateSubject(@JdbcConn(true) Connection con, String resourceId, String subject) throws SQLException {
		this.resourceDao.updateSubject(con, resourceId, subject);
	}

	@Post
	@Path("/industry")
	public void updateIndustry(@JdbcConn(true) Connection con, String resourceId, String industry) throws SQLException {
		this.resourceDao.updateIndustry(con, resourceId, industry);
	}

	@Post
	@Path("/descp")
	public void updateDescp(@JdbcConn(true) Connection con, String resourceId, String descp) throws SQLException {
		this.resourceDao.updateDescp(con, resourceId, descp);
	}
	
	@Post
	@Path("/hopePayMethod")
	public void updateHopePayMethod(@JdbcConn(true) Connection con, String resourceId, String hopePayMethod) throws SQLException {
		this.resourceDao.updateHopePayMethod(con, resourceId, hopePayMethod);
	}
	
	@Delete
	@Path("/{resourceId}")
	public void delete(@JdbcConn(true) Connection con, @PathVar String resourceId) throws SQLException {
		this.imageDao.deleteRes(con, resourceId);
		this.resourceDao.delete(con, resourceId);
	}
	
	@Get
	@Path("/pq")
	public PageQueryResult<Resource> queryPage(@JdbcConn(false) Connection con, @Nullable String key, @Nullable String subject, @Nullable String industry, @DefaultValue("10") int pageSize, @DefaultValue("1") int pageNo) throws SQLException {
		if(key!=null) key="%"+key+"%";
		if(subject!=null) subject ="%"+subject+"%";
		if(industry!=null)industry="%"+industry+"%";
		return this.resourceDao.queryPage(con, key, subject, industry, pageSize, pageNo);
	}
	
}
